# dimple: a proof of concept

Proof-of-concept package implementing dimple ('debiased inference made simple') from "Simplifying Debiased Inference via Automatic Differentiation and Probabilistic Programming" [[link](https://LINK_TO_BE_ADDED)]

## Installation

To install the package, make sure you have Python 3.8 or later and run the following command:

```bash
pip install pydimple
```

Once installed, it can be imported in Python via:

```Python
import dimple
```

## Usage

For examples, please refer to the [Examples.md](Examples.md) file.

## Acknowledgement

Much of dimple's core automatic differentiation code is from the excellent [Medium tutorial](https://towardsdatascience.com/build-your-own-automatic-differentiation-program-6ecd585eec2a) by [Jonathan Kernes](https://jmkernes.github.io/). Thank you, Jonathan, for letting me use it!

## Contributing

I'm not a software engineer, but I'm interested in developing this project further. If you share this interest and have relevant coding skills, please reach out! I'd love to collaborate.

\[[aluedtke@uw.edu](mailto:aluedtke@uw.edu)\]